@@ -37,6 +37,7 @@ describe 'vitrage::api' do
       is_expected.to contain_vitrage_config('api/port').with_value( params[:port] )
       is_expected.to contain_oslo__middleware('vitrage_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        :max_request_body_size        => '<SERVICE DEFAULT>',
       )
     end
 
@@ -71,6 +72,16 @@ describe 'vitrage::api' do
       )}
     end
 
+    context 'with max_request_body_size' do
+      before do
+        params.merge!({:max_request_body_size => 102400 })
+      end
+
+      it { is_expected.to contain_oslo__middleware('vitrage_config').with(
+        :max_request_body_size => 102400,
+      )}
+    end
+
     context 'with disabled service managing' do
       before do
         params.merge!({
